@@ -943,11 +943,6 @@ def pbdDict_bxReposRoot(
         'bx-blee/org-img-link',
         vcMode
     )
-    gitClone(
-        'blee/org-img-link',
-        'bx-blee/org-img-link',
-        vcMode
-    )
     gitClone(
         'blee/persian-input-method',
         'bx-blee/persian-input-method',
@@ -970,7 +965,10 @@ def pbdDict_bxReposRoot(
     gitClone('unisos-pip/icmExamples',  'unisos-pip/icmExamples', vcMode)
     gitClone('unisos-pip/x822Msg',  'unisos-pip/x822Msg', vcMode)
     gitClone('unisos-pip/utils',  'unisos-pip/utils', vcMode)
-    gitClone('unisos-pip/githubApi',  'unisos-pip/githubApi', vcMode)        
+    gitClone('unisos-pip/githubApi',  'unisos-pip/githubApi', vcMode)
+    gitClone('unisos-pip/cryptKeyring',  'unisos-pip/cryptKeyring', vcMode)
+    gitClone('unisos-pip/gcipher',  'unisos-pip/gcipher', vcMode)        
+    gitClone('unisos-pip/symCrypt',  'unisos-pip/symCrypt', vcMode)            
     
     gitCloneBase('bisos-pip',  'bisos-pip/base', vcMode)
     gitClone('bisos-pip/overview',  'bisos-pip/overview', vcMode)    
@@ -995,6 +993,8 @@ def pbdDict_bxReposRoot(
     gitClone('bisos-pip/core',  'bisos-pip/core', vcMode)
     gitClone('bisos-pip/coreDist',  'bisos-pip/coreDist', vcMode)
     gitClone('bisos-pip/full',  'bisos-pip/full', vcMode)
+    gitClone('bisos-pip/bashStandaloneIcmSeed',  'bisos-pip/bashStandaloneIcmSeed', vcMode)
+    gitClone('bisos-pip/provision',  'bisos-pip/provision', vcMode)    
 
     gitCloneBase('blee-pip',  'blee-pip/base', vcMode)
     gitClone('blee-pip/overview',  'blee-pip/overview', vcMode)    
@@ -1057,16 +1057,15 @@ def pbdDict_extRepos(
 
     pbdDict = collections.OrderedDict()
 
-    #root = bxReposRoot_baseObtain(baseDir)
+    # root = bxReposRoot_baseObtain(baseDir)
     root = baseDir
     pbdDict['/'] = bxpBaseDir.bxpObjGet_baseDir(root, '')
 
     if not vcMode:
         vcMode = "anon"
     
-    
     def fullDestPathGet(dstPathRel):
-        return( os.path.join(
+        return(os.path.join(
             root, dstPathRel,
         ))
 
